use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/DateTime/Locale.pm',
    'lib/DateTime/Locale/Base.pm',
    'lib/DateTime/Locale/Catalog.pm',
    'lib/DateTime/Locale/Conflicts.pm',
    'lib/DateTime/Locale/Data.pm',
    'lib/DateTime/Locale/FromData.pm',
    'lib/DateTime/Locale/Util.pm',
    'lib/DateTime/Locale/aa.pod',
    'lib/DateTime/Locale/aa_DJ.pod',
    'lib/DateTime/Locale/aa_ER.pod',
    'lib/DateTime/Locale/aa_ET.pod',
    'lib/DateTime/Locale/ab.pod',
    'lib/DateTime/Locale/ab_GE.pod',
    'lib/DateTime/Locale/af.pod',
    'lib/DateTime/Locale/af_NA.pod',
    'lib/DateTime/Locale/af_ZA.pod',
    'lib/DateTime/Locale/agq.pod',
    'lib/DateTime/Locale/agq_CM.pod',
    'lib/DateTime/Locale/ak.pod',
    'lib/DateTime/Locale/ak_GH.pod',
    'lib/DateTime/Locale/am.pod',
    'lib/DateTime/Locale/am_ET.pod',
    'lib/DateTime/Locale/an.pod',
    'lib/DateTime/Locale/an_ES.pod',
    'lib/DateTime/Locale/ann.pod',
    'lib/DateTime/Locale/ann_NG.pod',
    'lib/DateTime/Locale/apc_SY.pod',
    'lib/DateTime/Locale/ar.pod',
    'lib/DateTime/Locale/ar_001.pod',
    'lib/DateTime/Locale/ar_AE.pod',
    'lib/DateTime/Locale/ar_BH.pod',
    'lib/DateTime/Locale/ar_DJ.pod',
    'lib/DateTime/Locale/ar_DZ.pod',
    'lib/DateTime/Locale/ar_EG.pod',
    'lib/DateTime/Locale/ar_EH.pod',
    'lib/DateTime/Locale/ar_ER.pod',
    'lib/DateTime/Locale/ar_IL.pod',
    'lib/DateTime/Locale/ar_IQ.pod',
    'lib/DateTime/Locale/ar_JO.pod',
    'lib/DateTime/Locale/ar_KM.pod',
    'lib/DateTime/Locale/ar_KW.pod',
    'lib/DateTime/Locale/ar_LB.pod',
    'lib/DateTime/Locale/ar_LY.pod',
    'lib/DateTime/Locale/ar_MA.pod',
    'lib/DateTime/Locale/ar_MR.pod',
    'lib/DateTime/Locale/ar_OM.pod',
    'lib/DateTime/Locale/ar_PS.pod',
    'lib/DateTime/Locale/ar_QA.pod',
    'lib/DateTime/Locale/ar_SA.pod',
    'lib/DateTime/Locale/ar_SD.pod',
    'lib/DateTime/Locale/ar_SO.pod',
    'lib/DateTime/Locale/ar_SS.pod',
    'lib/DateTime/Locale/ar_SY.pod',
    'lib/DateTime/Locale/ar_TD.pod',
    'lib/DateTime/Locale/ar_TN.pod',
    'lib/DateTime/Locale/ar_YE.pod',
    'lib/DateTime/Locale/arn.pod',
    'lib/DateTime/Locale/arn_CL.pod',
    'lib/DateTime/Locale/as.pod',
    'lib/DateTime/Locale/as_IN.pod',
    'lib/DateTime/Locale/asa.pod',
    'lib/DateTime/Locale/asa_TZ.pod',
    'lib/DateTime/Locale/ast.pod',
    'lib/DateTime/Locale/ast_ES.pod',
    'lib/DateTime/Locale/az.pod',
    'lib/DateTime/Locale/az_Arab.pod',
    'lib/DateTime/Locale/az_Arab_IQ.pod',
    'lib/DateTime/Locale/az_Arab_IR.pod',
    'lib/DateTime/Locale/az_Arab_TR.pod',
    'lib/DateTime/Locale/az_Cyrl.pod',
    'lib/DateTime/Locale/az_Cyrl_AZ.pod',
    'lib/DateTime/Locale/az_Latn.pod',
    'lib/DateTime/Locale/az_Latn_AZ.pod',
    'lib/DateTime/Locale/ba.pod',
    'lib/DateTime/Locale/ba_RU.pod',
    'lib/DateTime/Locale/bal.pod',
    'lib/DateTime/Locale/bal_Arab.pod',
    'lib/DateTime/Locale/bal_Arab_PK.pod',
    'lib/DateTime/Locale/bal_Latn.pod',
    'lib/DateTime/Locale/bal_Latn_PK.pod',
    'lib/DateTime/Locale/bas.pod',
    'lib/DateTime/Locale/bas_CM.pod',
    'lib/DateTime/Locale/be.pod',
    'lib/DateTime/Locale/be_BY.pod',
    'lib/DateTime/Locale/be_tarask.pod',
    'lib/DateTime/Locale/bem.pod',
    'lib/DateTime/Locale/bem_ZM.pod',
    'lib/DateTime/Locale/bew.pod',
    'lib/DateTime/Locale/bew_ID.pod',
    'lib/DateTime/Locale/bez.pod',
    'lib/DateTime/Locale/bez_TZ.pod',
    'lib/DateTime/Locale/bg.pod',
    'lib/DateTime/Locale/bg_BG.pod',
    'lib/DateTime/Locale/bgc.pod',
    'lib/DateTime/Locale/bgc_IN.pod',
    'lib/DateTime/Locale/bgn.pod',
    'lib/DateTime/Locale/bgn_AE.pod',
    'lib/DateTime/Locale/bgn_AF.pod',
    'lib/DateTime/Locale/bgn_IR.pod',
    'lib/DateTime/Locale/bgn_OM.pod',
    'lib/DateTime/Locale/bgn_PK.pod',
    'lib/DateTime/Locale/bho.pod',
    'lib/DateTime/Locale/bho_IN.pod',
    'lib/DateTime/Locale/blo.pod',
    'lib/DateTime/Locale/blo_BJ.pod',
    'lib/DateTime/Locale/blt.pod',
    'lib/DateTime/Locale/blt_VN.pod',
    'lib/DateTime/Locale/bm.pod',
    'lib/DateTime/Locale/bm_ML.pod',
    'lib/DateTime/Locale/bm_Nkoo.pod',
    'lib/DateTime/Locale/bm_Nkoo_ML.pod',
    'lib/DateTime/Locale/bn.pod',
    'lib/DateTime/Locale/bn_BD.pod',
    'lib/DateTime/Locale/bn_IN.pod',
    'lib/DateTime/Locale/bo.pod',
    'lib/DateTime/Locale/bo_CN.pod',
    'lib/DateTime/Locale/bo_IN.pod',
    'lib/DateTime/Locale/br.pod',
    'lib/DateTime/Locale/br_FR.pod',
    'lib/DateTime/Locale/brx.pod',
    'lib/DateTime/Locale/brx_IN.pod',
    'lib/DateTime/Locale/bs.pod',
    'lib/DateTime/Locale/bs_Cyrl.pod',
    'lib/DateTime/Locale/bs_Cyrl_BA.pod',
    'lib/DateTime/Locale/bs_Latn.pod',
    'lib/DateTime/Locale/bs_Latn_BA.pod',
    'lib/DateTime/Locale/bss.pod',
    'lib/DateTime/Locale/bss_CM.pod',
    'lib/DateTime/Locale/byn.pod',
    'lib/DateTime/Locale/byn_ER.pod',
    'lib/DateTime/Locale/ca.pod',
    'lib/DateTime/Locale/ca_AD.pod',
    'lib/DateTime/Locale/ca_ES.pod',
    'lib/DateTime/Locale/ca_ES_valencia.pod',
    'lib/DateTime/Locale/ca_FR.pod',
    'lib/DateTime/Locale/ca_IT.pod',
    'lib/DateTime/Locale/cad.pod',
    'lib/DateTime/Locale/cad_US.pod',
    'lib/DateTime/Locale/cch.pod',
    'lib/DateTime/Locale/cch_NG.pod',
    'lib/DateTime/Locale/ccp.pod',
    'lib/DateTime/Locale/ccp_BD.pod',
    'lib/DateTime/Locale/ccp_IN.pod',
    'lib/DateTime/Locale/ce.pod',
    'lib/DateTime/Locale/ce_RU.pod',
    'lib/DateTime/Locale/ceb.pod',
    'lib/DateTime/Locale/ceb_PH.pod',
    'lib/DateTime/Locale/cgg.pod',
    'lib/DateTime/Locale/cgg_UG.pod',
    'lib/DateTime/Locale/cho.pod',
    'lib/DateTime/Locale/cho_US.pod',
    'lib/DateTime/Locale/chr.pod',
    'lib/DateTime/Locale/chr_US.pod',
    'lib/DateTime/Locale/cic.pod',
    'lib/DateTime/Locale/cic_US.pod',
    'lib/DateTime/Locale/ckb.pod',
    'lib/DateTime/Locale/ckb_IQ.pod',
    'lib/DateTime/Locale/ckb_IR.pod',
    'lib/DateTime/Locale/co.pod',
    'lib/DateTime/Locale/co_FR.pod',
    'lib/DateTime/Locale/cs.pod',
    'lib/DateTime/Locale/cs_CZ.pod',
    'lib/DateTime/Locale/csw.pod',
    'lib/DateTime/Locale/csw_CA.pod',
    'lib/DateTime/Locale/cu.pod',
    'lib/DateTime/Locale/cu_RU.pod',
    'lib/DateTime/Locale/cv.pod',
    'lib/DateTime/Locale/cv_RU.pod',
    'lib/DateTime/Locale/cy.pod',
    'lib/DateTime/Locale/cy_GB.pod',
    'lib/DateTime/Locale/da.pod',
    'lib/DateTime/Locale/da_DK.pod',
    'lib/DateTime/Locale/da_GL.pod',
    'lib/DateTime/Locale/dav.pod',
    'lib/DateTime/Locale/dav_KE.pod',
    'lib/DateTime/Locale/de.pod',
    'lib/DateTime/Locale/de_AT.pod',
    'lib/DateTime/Locale/de_BE.pod',
    'lib/DateTime/Locale/de_CH.pod',
    'lib/DateTime/Locale/de_DE.pod',
    'lib/DateTime/Locale/de_IT.pod',
    'lib/DateTime/Locale/de_LI.pod',
    'lib/DateTime/Locale/de_LU.pod',
    'lib/DateTime/Locale/dje.pod',
    'lib/DateTime/Locale/dje_NE.pod',
    'lib/DateTime/Locale/doi.pod',
    'lib/DateTime/Locale/doi_IN.pod',
    'lib/DateTime/Locale/dsb.pod',
    'lib/DateTime/Locale/dsb_DE.pod',
    'lib/DateTime/Locale/dua.pod',
    'lib/DateTime/Locale/dua_CM.pod',
    'lib/DateTime/Locale/dv.pod',
    'lib/DateTime/Locale/dv_MV.pod',
    'lib/DateTime/Locale/dyo.pod',
    'lib/DateTime/Locale/dyo_SN.pod',
    'lib/DateTime/Locale/dz.pod',
    'lib/DateTime/Locale/dz_BT.pod',
    'lib/DateTime/Locale/ebu.pod',
    'lib/DateTime/Locale/ebu_KE.pod',
    'lib/DateTime/Locale/ee.pod',
    'lib/DateTime/Locale/ee_GH.pod',
    'lib/DateTime/Locale/ee_TG.pod',
    'lib/DateTime/Locale/el.pod',
    'lib/DateTime/Locale/el_CY.pod',
    'lib/DateTime/Locale/el_GR.pod',
    'lib/DateTime/Locale/el_polyton.pod',
    'lib/DateTime/Locale/en.pod',
    'lib/DateTime/Locale/en_001.pod',
    'lib/DateTime/Locale/en_150.pod',
    'lib/DateTime/Locale/en_AE.pod',
    'lib/DateTime/Locale/en_AG.pod',
    'lib/DateTime/Locale/en_AI.pod',
    'lib/DateTime/Locale/en_AS.pod',
    'lib/DateTime/Locale/en_AT.pod',
    'lib/DateTime/Locale/en_AU.pod',
    'lib/DateTime/Locale/en_BB.pod',
    'lib/DateTime/Locale/en_BE.pod',
    'lib/DateTime/Locale/en_BI.pod',
    'lib/DateTime/Locale/en_BM.pod',
    'lib/DateTime/Locale/en_BS.pod',
    'lib/DateTime/Locale/en_BW.pod',
    'lib/DateTime/Locale/en_BZ.pod',
    'lib/DateTime/Locale/en_CA.pod',
    'lib/DateTime/Locale/en_CC.pod',
    'lib/DateTime/Locale/en_CH.pod',
    'lib/DateTime/Locale/en_CK.pod',
    'lib/DateTime/Locale/en_CM.pod',
    'lib/DateTime/Locale/en_CX.pod',
    'lib/DateTime/Locale/en_CY.pod',
    'lib/DateTime/Locale/en_DE.pod',
    'lib/DateTime/Locale/en_DG.pod',
    'lib/DateTime/Locale/en_DK.pod',
    'lib/DateTime/Locale/en_DM.pod',
    'lib/DateTime/Locale/en_Dsrt.pod',
    'lib/DateTime/Locale/en_Dsrt_US.pod',
    'lib/DateTime/Locale/en_ER.pod',
    'lib/DateTime/Locale/en_FI.pod',
    'lib/DateTime/Locale/en_FJ.pod',
    'lib/DateTime/Locale/en_FK.pod',
    'lib/DateTime/Locale/en_FM.pod',
    'lib/DateTime/Locale/en_GB.pod',
    'lib/DateTime/Locale/en_GD.pod',
    'lib/DateTime/Locale/en_GG.pod',
    'lib/DateTime/Locale/en_GH.pod',
    'lib/DateTime/Locale/en_GI.pod',
    'lib/DateTime/Locale/en_GM.pod',
    'lib/DateTime/Locale/en_GU.pod',
    'lib/DateTime/Locale/en_GY.pod',
    'lib/DateTime/Locale/en_HK.pod',
    'lib/DateTime/Locale/en_ID.pod',
    'lib/DateTime/Locale/en_IE.pod',
    'lib/DateTime/Locale/en_IL.pod',
    'lib/DateTime/Locale/en_IM.pod',
    'lib/DateTime/Locale/en_IN.pod',
    'lib/DateTime/Locale/en_IO.pod',
    'lib/DateTime/Locale/en_JE.pod',
    'lib/DateTime/Locale/en_JM.pod',
    'lib/DateTime/Locale/en_KE.pod',
    'lib/DateTime/Locale/en_KI.pod',
    'lib/DateTime/Locale/en_KN.pod',
    'lib/DateTime/Locale/en_KY.pod',
    'lib/DateTime/Locale/en_LC.pod',
    'lib/DateTime/Locale/en_LR.pod',
    'lib/DateTime/Locale/en_LS.pod',
    'lib/DateTime/Locale/en_MG.pod',
    'lib/DateTime/Locale/en_MH.pod',
    'lib/DateTime/Locale/en_MO.pod',
    'lib/DateTime/Locale/en_MP.pod',
    'lib/DateTime/Locale/en_MS.pod',
    'lib/DateTime/Locale/en_MT.pod',
    'lib/DateTime/Locale/en_MU.pod',
    'lib/DateTime/Locale/en_MV.pod',
    'lib/DateTime/Locale/en_MW.pod',
    'lib/DateTime/Locale/en_MY.pod',
    'lib/DateTime/Locale/en_NA.pod',
    'lib/DateTime/Locale/en_NF.pod',
    'lib/DateTime/Locale/en_NG.pod',
    'lib/DateTime/Locale/en_NL.pod',
    'lib/DateTime/Locale/en_NR.pod',
    'lib/DateTime/Locale/en_NU.pod',
    'lib/DateTime/Locale/en_NZ.pod',
    'lib/DateTime/Locale/en_PG.pod',
    'lib/DateTime/Locale/en_PH.pod',
    'lib/DateTime/Locale/en_PK.pod',
    'lib/DateTime/Locale/en_PN.pod',
    'lib/DateTime/Locale/en_PR.pod',
    'lib/DateTime/Locale/en_PW.pod',
    'lib/DateTime/Locale/en_RW.pod',
    'lib/DateTime/Locale/en_SB.pod',
    'lib/DateTime/Locale/en_SC.pod',
    'lib/DateTime/Locale/en_SD.pod',
    'lib/DateTime/Locale/en_SE.pod',
    'lib/DateTime/Locale/en_SG.pod',
    'lib/DateTime/Locale/en_SH.pod',
    'lib/DateTime/Locale/en_SI.pod',
    'lib/DateTime/Locale/en_SL.pod',
    'lib/DateTime/Locale/en_SS.pod',
    'lib/DateTime/Locale/en_SX.pod',
    'lib/DateTime/Locale/en_SZ.pod',
    'lib/DateTime/Locale/en_Shaw.pod',
    'lib/DateTime/Locale/en_Shaw_GB.pod',
    'lib/DateTime/Locale/en_TC.pod',
    'lib/DateTime/Locale/en_TK.pod',
    'lib/DateTime/Locale/en_TO.pod',
    'lib/DateTime/Locale/en_TT.pod',
    'lib/DateTime/Locale/en_TV.pod',
    'lib/DateTime/Locale/en_TZ.pod',
    'lib/DateTime/Locale/en_UG.pod',
    'lib/DateTime/Locale/en_UM.pod',
    'lib/DateTime/Locale/en_US.pod',
    'lib/DateTime/Locale/en_VC.pod',
    'lib/DateTime/Locale/en_VG.pod',
    'lib/DateTime/Locale/en_VI.pod',
    'lib/DateTime/Locale/en_VU.pod',
    'lib/DateTime/Locale/en_WS.pod',
    'lib/DateTime/Locale/en_ZA.pod',
    'lib/DateTime/Locale/en_ZM.pod',
    'lib/DateTime/Locale/en_ZW.pod',
    'lib/DateTime/Locale/eo.pod',
    'lib/DateTime/Locale/eo_001.pod',
    'lib/DateTime/Locale/es.pod',
    'lib/DateTime/Locale/es_419.pod',
    'lib/DateTime/Locale/es_AR.pod',
    'lib/DateTime/Locale/es_BO.pod',
    'lib/DateTime/Locale/es_BR.pod',
    'lib/DateTime/Locale/es_BZ.pod',
    'lib/DateTime/Locale/es_CL.pod',
    'lib/DateTime/Locale/es_CO.pod',
    'lib/DateTime/Locale/es_CR.pod',
    'lib/DateTime/Locale/es_CU.pod',
    'lib/DateTime/Locale/es_DO.pod',
    'lib/DateTime/Locale/es_EA.pod',
    'lib/DateTime/Locale/es_EC.pod',
    'lib/DateTime/Locale/es_ES.pod',
    'lib/DateTime/Locale/es_GQ.pod',
    'lib/DateTime/Locale/es_GT.pod',
    'lib/DateTime/Locale/es_HN.pod',
    'lib/DateTime/Locale/es_IC.pod',
    'lib/DateTime/Locale/es_MX.pod',
    'lib/DateTime/Locale/es_NI.pod',
    'lib/DateTime/Locale/es_PA.pod',
    'lib/DateTime/Locale/es_PE.pod',
    'lib/DateTime/Locale/es_PH.pod',
    'lib/DateTime/Locale/es_PR.pod',
    'lib/DateTime/Locale/es_PY.pod',
    'lib/DateTime/Locale/es_SV.pod',
    'lib/DateTime/Locale/es_US.pod',
    'lib/DateTime/Locale/es_UY.pod',
    'lib/DateTime/Locale/es_VE.pod',
    'lib/DateTime/Locale/et.pod',
    'lib/DateTime/Locale/et_EE.pod',
    'lib/DateTime/Locale/eu.pod',
    'lib/DateTime/Locale/eu_ES.pod',
    'lib/DateTime/Locale/ewo.pod',
    'lib/DateTime/Locale/ewo_CM.pod',
    'lib/DateTime/Locale/fa.pod',
    'lib/DateTime/Locale/fa_AF.pod',
    'lib/DateTime/Locale/fa_IR.pod',
    'lib/DateTime/Locale/ff.pod',
    'lib/DateTime/Locale/ff_Adlm.pod',
    'lib/DateTime/Locale/ff_Adlm_BF.pod',
    'lib/DateTime/Locale/ff_Adlm_CM.pod',
    'lib/DateTime/Locale/ff_Adlm_GH.pod',
    'lib/DateTime/Locale/ff_Adlm_GM.pod',
    'lib/DateTime/Locale/ff_Adlm_GN.pod',
    'lib/DateTime/Locale/ff_Adlm_GW.pod',
    'lib/DateTime/Locale/ff_Adlm_LR.pod',
    'lib/DateTime/Locale/ff_Adlm_MR.pod',
    'lib/DateTime/Locale/ff_Adlm_NE.pod',
    'lib/DateTime/Locale/ff_Adlm_NG.pod',
    'lib/DateTime/Locale/ff_Adlm_SL.pod',
    'lib/DateTime/Locale/ff_Adlm_SN.pod',
    'lib/DateTime/Locale/ff_Latn.pod',
    'lib/DateTime/Locale/ff_Latn_BF.pod',
    'lib/DateTime/Locale/ff_Latn_CM.pod',
    'lib/DateTime/Locale/ff_Latn_GH.pod',
    'lib/DateTime/Locale/ff_Latn_GM.pod',
    'lib/DateTime/Locale/ff_Latn_GN.pod',
    'lib/DateTime/Locale/ff_Latn_GW.pod',
    'lib/DateTime/Locale/ff_Latn_LR.pod',
    'lib/DateTime/Locale/ff_Latn_MR.pod',
    'lib/DateTime/Locale/ff_Latn_NE.pod',
    'lib/DateTime/Locale/ff_Latn_NG.pod',
    'lib/DateTime/Locale/ff_Latn_SL.pod',
    'lib/DateTime/Locale/ff_Latn_SN.pod',
    'lib/DateTime/Locale/fi.pod',
    'lib/DateTime/Locale/fi_FI.pod',
    'lib/DateTime/Locale/fil.pod',
    'lib/DateTime/Locale/fil_PH.pod',
    'lib/DateTime/Locale/fo.pod',
    'lib/DateTime/Locale/fo_DK.pod',
    'lib/DateTime/Locale/fo_FO.pod',
    'lib/DateTime/Locale/fr.pod',
    'lib/DateTime/Locale/fr_BE.pod',
    'lib/DateTime/Locale/fr_BF.pod',
    'lib/DateTime/Locale/fr_BI.pod',
    'lib/DateTime/Locale/fr_BJ.pod',
    'lib/DateTime/Locale/fr_BL.pod',
    'lib/DateTime/Locale/fr_CA.pod',
    'lib/DateTime/Locale/fr_CD.pod',
    'lib/DateTime/Locale/fr_CF.pod',
    'lib/DateTime/Locale/fr_CG.pod',
    'lib/DateTime/Locale/fr_CH.pod',
    'lib/DateTime/Locale/fr_CI.pod',
    'lib/DateTime/Locale/fr_CM.pod',
    'lib/DateTime/Locale/fr_DJ.pod',
    'lib/DateTime/Locale/fr_DZ.pod',
    'lib/DateTime/Locale/fr_FR.pod',
    'lib/DateTime/Locale/fr_GA.pod',
    'lib/DateTime/Locale/fr_GF.pod',
    'lib/DateTime/Locale/fr_GN.pod',
    'lib/DateTime/Locale/fr_GP.pod',
    'lib/DateTime/Locale/fr_GQ.pod',
    'lib/DateTime/Locale/fr_HT.pod',
    'lib/DateTime/Locale/fr_KM.pod',
    'lib/DateTime/Locale/fr_LU.pod',
    'lib/DateTime/Locale/fr_MA.pod',
    'lib/DateTime/Locale/fr_MC.pod',
    'lib/DateTime/Locale/fr_MF.pod',
    'lib/DateTime/Locale/fr_MG.pod',
    'lib/DateTime/Locale/fr_ML.pod',
    'lib/DateTime/Locale/fr_MQ.pod',
    'lib/DateTime/Locale/fr_MR.pod',
    'lib/DateTime/Locale/fr_MU.pod',
    'lib/DateTime/Locale/fr_NC.pod',
    'lib/DateTime/Locale/fr_NE.pod',
    'lib/DateTime/Locale/fr_PF.pod',
    'lib/DateTime/Locale/fr_PM.pod',
    'lib/DateTime/Locale/fr_RE.pod',
    'lib/DateTime/Locale/fr_RW.pod',
    'lib/DateTime/Locale/fr_SC.pod',
    'lib/DateTime/Locale/fr_SN.pod',
    'lib/DateTime/Locale/fr_SY.pod',
    'lib/DateTime/Locale/fr_TD.pod',
    'lib/DateTime/Locale/fr_TG.pod',
    'lib/DateTime/Locale/fr_TN.pod',
    'lib/DateTime/Locale/fr_VU.pod',
    'lib/DateTime/Locale/fr_WF.pod',
    'lib/DateTime/Locale/fr_YT.pod',
    'lib/DateTime/Locale/frr.pod',
    'lib/DateTime/Locale/frr_DE.pod',
    'lib/DateTime/Locale/fur.pod',
    'lib/DateTime/Locale/fur_IT.pod',
    'lib/DateTime/Locale/fy.pod',
    'lib/DateTime/Locale/fy_NL.pod',
    'lib/DateTime/Locale/ga.pod',
    'lib/DateTime/Locale/ga_GB.pod',
    'lib/DateTime/Locale/ga_IE.pod',
    'lib/DateTime/Locale/gaa.pod',
    'lib/DateTime/Locale/gaa_GH.pod',
    'lib/DateTime/Locale/gd.pod',
    'lib/DateTime/Locale/gd_GB.pod',
    'lib/DateTime/Locale/gez.pod',
    'lib/DateTime/Locale/gez_ER.pod',
    'lib/DateTime/Locale/gez_ET.pod',
    'lib/DateTime/Locale/gl.pod',
    'lib/DateTime/Locale/gl_ES.pod',
    'lib/DateTime/Locale/gn.pod',
    'lib/DateTime/Locale/gn_PY.pod',
    'lib/DateTime/Locale/gsw.pod',
    'lib/DateTime/Locale/gsw_CH.pod',
    'lib/DateTime/Locale/gsw_FR.pod',
    'lib/DateTime/Locale/gsw_LI.pod',
    'lib/DateTime/Locale/gu.pod',
    'lib/DateTime/Locale/gu_IN.pod',
    'lib/DateTime/Locale/guz.pod',
    'lib/DateTime/Locale/guz_KE.pod',
    'lib/DateTime/Locale/gv.pod',
    'lib/DateTime/Locale/gv_IM.pod',
    'lib/DateTime/Locale/ha.pod',
    'lib/DateTime/Locale/ha_Arab.pod',
    'lib/DateTime/Locale/ha_Arab_NG.pod',
    'lib/DateTime/Locale/ha_Arab_SD.pod',
    'lib/DateTime/Locale/ha_GH.pod',
    'lib/DateTime/Locale/ha_NE.pod',
    'lib/DateTime/Locale/ha_NG.pod',
    'lib/DateTime/Locale/haw.pod',
    'lib/DateTime/Locale/haw_US.pod',
    'lib/DateTime/Locale/he.pod',
    'lib/DateTime/Locale/he_IL.pod',
    'lib/DateTime/Locale/hi.pod',
    'lib/DateTime/Locale/hi_IN.pod',
    'lib/DateTime/Locale/hi_Latn.pod',
    'lib/DateTime/Locale/hi_Latn_IN.pod',
    'lib/DateTime/Locale/hnj.pod',
    'lib/DateTime/Locale/hnj_Hmnp.pod',
    'lib/DateTime/Locale/hnj_Hmnp_US.pod',
    'lib/DateTime/Locale/hr.pod',
    'lib/DateTime/Locale/hr_BA.pod',
    'lib/DateTime/Locale/hr_HR.pod',
    'lib/DateTime/Locale/hsb.pod',
    'lib/DateTime/Locale/hsb_DE.pod',
    'lib/DateTime/Locale/hu.pod',
    'lib/DateTime/Locale/hu_HU.pod',
    'lib/DateTime/Locale/hy.pod',
    'lib/DateTime/Locale/hy_AM.pod',
    'lib/DateTime/Locale/ia.pod',
    'lib/DateTime/Locale/ia_001.pod',
    'lib/DateTime/Locale/id.pod',
    'lib/DateTime/Locale/id_ID.pod',
    'lib/DateTime/Locale/ie.pod',
    'lib/DateTime/Locale/ie_EE.pod',
    'lib/DateTime/Locale/ig.pod',
    'lib/DateTime/Locale/ig_NG.pod',
    'lib/DateTime/Locale/ii.pod',
    'lib/DateTime/Locale/ii_CN.pod',
    'lib/DateTime/Locale/io.pod',
    'lib/DateTime/Locale/io_001.pod',
    'lib/DateTime/Locale/is.pod',
    'lib/DateTime/Locale/is_IS.pod',
    'lib/DateTime/Locale/it.pod',
    'lib/DateTime/Locale/it_CH.pod',
    'lib/DateTime/Locale/it_IT.pod',
    'lib/DateTime/Locale/it_SM.pod',
    'lib/DateTime/Locale/it_VA.pod',
    'lib/DateTime/Locale/iu.pod',
    'lib/DateTime/Locale/iu_CA.pod',
    'lib/DateTime/Locale/iu_Latn.pod',
    'lib/DateTime/Locale/iu_Latn_CA.pod',
    'lib/DateTime/Locale/ja.pod',
    'lib/DateTime/Locale/ja_JP.pod',
    'lib/DateTime/Locale/jbo.pod',
    'lib/DateTime/Locale/jbo_001.pod',
    'lib/DateTime/Locale/jgo.pod',
    'lib/DateTime/Locale/jgo_CM.pod',
    'lib/DateTime/Locale/jmc.pod',
    'lib/DateTime/Locale/jmc_TZ.pod',
    'lib/DateTime/Locale/jv.pod',
    'lib/DateTime/Locale/jv_ID.pod',
    'lib/DateTime/Locale/ka.pod',
    'lib/DateTime/Locale/ka_GE.pod',
    'lib/DateTime/Locale/kab.pod',
    'lib/DateTime/Locale/kab_DZ.pod',
    'lib/DateTime/Locale/kaj.pod',
    'lib/DateTime/Locale/kaj_NG.pod',
    'lib/DateTime/Locale/kam.pod',
    'lib/DateTime/Locale/kam_KE.pod',
    'lib/DateTime/Locale/kcg.pod',
    'lib/DateTime/Locale/kcg_NG.pod',
    'lib/DateTime/Locale/kde.pod',
    'lib/DateTime/Locale/kde_TZ.pod',
    'lib/DateTime/Locale/kea.pod',
    'lib/DateTime/Locale/kea_CV.pod',
    'lib/DateTime/Locale/ken.pod',
    'lib/DateTime/Locale/ken_CM.pod',
    'lib/DateTime/Locale/kgp.pod',
    'lib/DateTime/Locale/kgp_BR.pod',
    'lib/DateTime/Locale/khq.pod',
    'lib/DateTime/Locale/khq_ML.pod',
    'lib/DateTime/Locale/ki.pod',
    'lib/DateTime/Locale/ki_KE.pod',
    'lib/DateTime/Locale/kk.pod',
    'lib/DateTime/Locale/kk_KZ.pod',
    'lib/DateTime/Locale/kkj.pod',
    'lib/DateTime/Locale/kkj_CM.pod',
    'lib/DateTime/Locale/kl.pod',
    'lib/DateTime/Locale/kl_GL.pod',
    'lib/DateTime/Locale/kln.pod',
    'lib/DateTime/Locale/kln_KE.pod',
    'lib/DateTime/Locale/km.pod',
    'lib/DateTime/Locale/km_KH.pod',
    'lib/DateTime/Locale/kn.pod',
    'lib/DateTime/Locale/kn_IN.pod',
    'lib/DateTime/Locale/ko.pod',
    'lib/DateTime/Locale/ko_CN.pod',
    'lib/DateTime/Locale/ko_KP.pod',
    'lib/DateTime/Locale/ko_KR.pod',
    'lib/DateTime/Locale/kok.pod',
    'lib/DateTime/Locale/kok_IN.pod',
    'lib/DateTime/Locale/kpe.pod',
    'lib/DateTime/Locale/kpe_GN.pod',
    'lib/DateTime/Locale/kpe_LR.pod',
    'lib/DateTime/Locale/ks.pod',
    'lib/DateTime/Locale/ks_Arab.pod',
    'lib/DateTime/Locale/ks_Arab_IN.pod',
    'lib/DateTime/Locale/ks_Deva.pod',
    'lib/DateTime/Locale/ks_Deva_IN.pod',
    'lib/DateTime/Locale/ksb.pod',
    'lib/DateTime/Locale/ksb_TZ.pod',
    'lib/DateTime/Locale/ksf.pod',
    'lib/DateTime/Locale/ksf_CM.pod',
    'lib/DateTime/Locale/ksh.pod',
    'lib/DateTime/Locale/ksh_DE.pod',
    'lib/DateTime/Locale/ku.pod',
    'lib/DateTime/Locale/ku_TR.pod',
    'lib/DateTime/Locale/kw.pod',
    'lib/DateTime/Locale/kw_GB.pod',
    'lib/DateTime/Locale/kxv.pod',
    'lib/DateTime/Locale/kxv_Deva.pod',
    'lib/DateTime/Locale/kxv_Deva_IN.pod',
    'lib/DateTime/Locale/kxv_Latn.pod',
    'lib/DateTime/Locale/kxv_Latn_IN.pod',
    'lib/DateTime/Locale/kxv_Orya.pod',
    'lib/DateTime/Locale/kxv_Orya_IN.pod',
    'lib/DateTime/Locale/kxv_Telu.pod',
    'lib/DateTime/Locale/kxv_Telu_IN.pod',
    'lib/DateTime/Locale/ky.pod',
    'lib/DateTime/Locale/ky_KG.pod',
    'lib/DateTime/Locale/la.pod',
    'lib/DateTime/Locale/la_VA.pod',
    'lib/DateTime/Locale/lag.pod',
    'lib/DateTime/Locale/lag_TZ.pod',
    'lib/DateTime/Locale/lb.pod',
    'lib/DateTime/Locale/lb_LU.pod',
    'lib/DateTime/Locale/lg.pod',
    'lib/DateTime/Locale/lg_UG.pod',
    'lib/DateTime/Locale/lij.pod',
    'lib/DateTime/Locale/lij_IT.pod',
    'lib/DateTime/Locale/lkt.pod',
    'lib/DateTime/Locale/lkt_US.pod',
    'lib/DateTime/Locale/lmo.pod',
    'lib/DateTime/Locale/lmo_IT.pod',
    'lib/DateTime/Locale/ln.pod',
    'lib/DateTime/Locale/ln_AO.pod',
    'lib/DateTime/Locale/ln_CD.pod',
    'lib/DateTime/Locale/ln_CF.pod',
    'lib/DateTime/Locale/ln_CG.pod',
    'lib/DateTime/Locale/lo.pod',
    'lib/DateTime/Locale/lo_LA.pod',
    'lib/DateTime/Locale/lrc.pod',
    'lib/DateTime/Locale/lrc_IQ.pod',
    'lib/DateTime/Locale/lrc_IR.pod',
    'lib/DateTime/Locale/lt.pod',
    'lib/DateTime/Locale/lt_LT.pod',
    'lib/DateTime/Locale/lu.pod',
    'lib/DateTime/Locale/lu_CD.pod',
    'lib/DateTime/Locale/luo.pod',
    'lib/DateTime/Locale/luo_KE.pod',
    'lib/DateTime/Locale/luy.pod',
    'lib/DateTime/Locale/luy_KE.pod',
    'lib/DateTime/Locale/lv.pod',
    'lib/DateTime/Locale/lv_LV.pod',
    'lib/DateTime/Locale/mai.pod',
    'lib/DateTime/Locale/mai_IN.pod',
    'lib/DateTime/Locale/mas.pod',
    'lib/DateTime/Locale/mas_KE.pod',
    'lib/DateTime/Locale/mas_TZ.pod',
    'lib/DateTime/Locale/mdf.pod',
    'lib/DateTime/Locale/mdf_RU.pod',
    'lib/DateTime/Locale/mer.pod',
    'lib/DateTime/Locale/mer_KE.pod',
    'lib/DateTime/Locale/mfe.pod',
    'lib/DateTime/Locale/mfe_MU.pod',
    'lib/DateTime/Locale/mg.pod',
    'lib/DateTime/Locale/mg_MG.pod',
    'lib/DateTime/Locale/mgh.pod',
    'lib/DateTime/Locale/mgh_MZ.pod',
    'lib/DateTime/Locale/mgo.pod',
    'lib/DateTime/Locale/mgo_CM.pod',
    'lib/DateTime/Locale/mi.pod',
    'lib/DateTime/Locale/mi_NZ.pod',
    'lib/DateTime/Locale/mic.pod',
    'lib/DateTime/Locale/mic_CA.pod',
    'lib/DateTime/Locale/mk.pod',
    'lib/DateTime/Locale/mk_MK.pod',
    'lib/DateTime/Locale/ml.pod',
    'lib/DateTime/Locale/ml_IN.pod',
    'lib/DateTime/Locale/mn.pod',
    'lib/DateTime/Locale/mn_MN.pod',
    'lib/DateTime/Locale/mn_Mong.pod',
    'lib/DateTime/Locale/mn_Mong_CN.pod',
    'lib/DateTime/Locale/mn_Mong_MN.pod',
    'lib/DateTime/Locale/mni.pod',
    'lib/DateTime/Locale/mni_Beng.pod',
    'lib/DateTime/Locale/mni_Beng_IN.pod',
    'lib/DateTime/Locale/mni_Mtei.pod',
    'lib/DateTime/Locale/mni_Mtei_IN.pod',
    'lib/DateTime/Locale/moh.pod',
    'lib/DateTime/Locale/moh_CA.pod',
    'lib/DateTime/Locale/mr.pod',
    'lib/DateTime/Locale/mr_IN.pod',
    'lib/DateTime/Locale/ms.pod',
    'lib/DateTime/Locale/ms_Arab.pod',
    'lib/DateTime/Locale/ms_Arab_BN.pod',
    'lib/DateTime/Locale/ms_Arab_MY.pod',
    'lib/DateTime/Locale/ms_BN.pod',
    'lib/DateTime/Locale/ms_ID.pod',
    'lib/DateTime/Locale/ms_MY.pod',
    'lib/DateTime/Locale/ms_SG.pod',
    'lib/DateTime/Locale/mt.pod',
    'lib/DateTime/Locale/mt_MT.pod',
    'lib/DateTime/Locale/mua.pod',
    'lib/DateTime/Locale/mua_CM.pod',
    'lib/DateTime/Locale/mus.pod',
    'lib/DateTime/Locale/mus_US.pod',
    'lib/DateTime/Locale/my.pod',
    'lib/DateTime/Locale/my_MM.pod',
    'lib/DateTime/Locale/myv.pod',
    'lib/DateTime/Locale/myv_RU.pod',
    'lib/DateTime/Locale/mzn.pod',
    'lib/DateTime/Locale/mzn_IR.pod',
    'lib/DateTime/Locale/naq.pod',
    'lib/DateTime/Locale/naq_NA.pod',
    'lib/DateTime/Locale/nb.pod',
    'lib/DateTime/Locale/nb_NO.pod',
    'lib/DateTime/Locale/nb_SJ.pod',
    'lib/DateTime/Locale/nd.pod',
    'lib/DateTime/Locale/nd_ZW.pod',
    'lib/DateTime/Locale/nds.pod',
    'lib/DateTime/Locale/nds_DE.pod',
    'lib/DateTime/Locale/nds_NL.pod',
    'lib/DateTime/Locale/ne.pod',
    'lib/DateTime/Locale/ne_IN.pod',
    'lib/DateTime/Locale/ne_NP.pod',
    'lib/DateTime/Locale/nl.pod',
    'lib/DateTime/Locale/nl_AW.pod',
    'lib/DateTime/Locale/nl_BE.pod',
    'lib/DateTime/Locale/nl_BQ.pod',
    'lib/DateTime/Locale/nl_CW.pod',
    'lib/DateTime/Locale/nl_NL.pod',
    'lib/DateTime/Locale/nl_SR.pod',
    'lib/DateTime/Locale/nl_SX.pod',
    'lib/DateTime/Locale/nmg.pod',
    'lib/DateTime/Locale/nmg_CM.pod',
    'lib/DateTime/Locale/nn.pod',
    'lib/DateTime/Locale/nn_NO.pod',
    'lib/DateTime/Locale/nnh.pod',
    'lib/DateTime/Locale/nnh_CM.pod',
    'lib/DateTime/Locale/no.pod',
    'lib/DateTime/Locale/nqo.pod',
    'lib/DateTime/Locale/nqo_GN.pod',
    'lib/DateTime/Locale/nr.pod',
    'lib/DateTime/Locale/nr_ZA.pod',
    'lib/DateTime/Locale/nso.pod',
    'lib/DateTime/Locale/nso_ZA.pod',
    'lib/DateTime/Locale/nus.pod',
    'lib/DateTime/Locale/nus_SS.pod',
    'lib/DateTime/Locale/nv.pod',
    'lib/DateTime/Locale/nv_US.pod',
    'lib/DateTime/Locale/ny.pod',
    'lib/DateTime/Locale/ny_MW.pod',
    'lib/DateTime/Locale/nyn.pod',
    'lib/DateTime/Locale/nyn_UG.pod',
    'lib/DateTime/Locale/oc.pod',
    'lib/DateTime/Locale/oc_ES.pod',
    'lib/DateTime/Locale/oc_FR.pod',
    'lib/DateTime/Locale/om.pod',
    'lib/DateTime/Locale/om_ET.pod',
    'lib/DateTime/Locale/om_KE.pod',
    'lib/DateTime/Locale/or.pod',
    'lib/DateTime/Locale/or_IN.pod',
    'lib/DateTime/Locale/os.pod',
    'lib/DateTime/Locale/os_GE.pod',
    'lib/DateTime/Locale/os_RU.pod',
    'lib/DateTime/Locale/osa.pod',
    'lib/DateTime/Locale/osa_US.pod',
    'lib/DateTime/Locale/pa.pod',
    'lib/DateTime/Locale/pa_Arab.pod',
    'lib/DateTime/Locale/pa_Arab_PK.pod',
    'lib/DateTime/Locale/pa_Guru.pod',
    'lib/DateTime/Locale/pa_Guru_IN.pod',
    'lib/DateTime/Locale/pap.pod',
    'lib/DateTime/Locale/pap_AW.pod',
    'lib/DateTime/Locale/pap_CW.pod',
    'lib/DateTime/Locale/pcm.pod',
    'lib/DateTime/Locale/pcm_NG.pod',
    'lib/DateTime/Locale/pis.pod',
    'lib/DateTime/Locale/pis_SB.pod',
    'lib/DateTime/Locale/pl.pod',
    'lib/DateTime/Locale/pl_PL.pod',
    'lib/DateTime/Locale/prg.pod',
    'lib/DateTime/Locale/prg_PL.pod',
    'lib/DateTime/Locale/ps.pod',
    'lib/DateTime/Locale/ps_AF.pod',
    'lib/DateTime/Locale/ps_PK.pod',
    'lib/DateTime/Locale/pt.pod',
    'lib/DateTime/Locale/pt_AO.pod',
    'lib/DateTime/Locale/pt_BR.pod',
    'lib/DateTime/Locale/pt_CH.pod',
    'lib/DateTime/Locale/pt_CV.pod',
    'lib/DateTime/Locale/pt_GQ.pod',
    'lib/DateTime/Locale/pt_GW.pod',
    'lib/DateTime/Locale/pt_LU.pod',
    'lib/DateTime/Locale/pt_MO.pod',
    'lib/DateTime/Locale/pt_MZ.pod',
    'lib/DateTime/Locale/pt_PT.pod',
    'lib/DateTime/Locale/pt_ST.pod',
    'lib/DateTime/Locale/pt_TL.pod',
    'lib/DateTime/Locale/qu.pod',
    'lib/DateTime/Locale/qu_BO.pod',
    'lib/DateTime/Locale/qu_EC.pod',
    'lib/DateTime/Locale/qu_PE.pod',
    'lib/DateTime/Locale/quc.pod',
    'lib/DateTime/Locale/quc_GT.pod',
    'lib/DateTime/Locale/raj.pod',
    'lib/DateTime/Locale/raj_IN.pod',
    'lib/DateTime/Locale/rhg.pod',
    'lib/DateTime/Locale/rhg_Rohg.pod',
    'lib/DateTime/Locale/rhg_Rohg_BD.pod',
    'lib/DateTime/Locale/rhg_Rohg_MM.pod',
    'lib/DateTime/Locale/rif.pod',
    'lib/DateTime/Locale/rif_MA.pod',
    'lib/DateTime/Locale/rm.pod',
    'lib/DateTime/Locale/rm_CH.pod',
    'lib/DateTime/Locale/rn.pod',
    'lib/DateTime/Locale/rn_BI.pod',
    'lib/DateTime/Locale/ro.pod',
    'lib/DateTime/Locale/ro_MD.pod',
    'lib/DateTime/Locale/ro_RO.pod',
    'lib/DateTime/Locale/rof.pod',
    'lib/DateTime/Locale/rof_TZ.pod',
    'lib/DateTime/Locale/ru.pod',
    'lib/DateTime/Locale/ru_BY.pod',
    'lib/DateTime/Locale/ru_KG.pod',
    'lib/DateTime/Locale/ru_KZ.pod',
    'lib/DateTime/Locale/ru_MD.pod',
    'lib/DateTime/Locale/ru_RU.pod',
    'lib/DateTime/Locale/ru_UA.pod',
    'lib/DateTime/Locale/rw.pod',
    'lib/DateTime/Locale/rw_RW.pod',
    'lib/DateTime/Locale/rwk.pod',
    'lib/DateTime/Locale/rwk_TZ.pod',
    'lib/DateTime/Locale/sa.pod',
    'lib/DateTime/Locale/sa_IN.pod',
    'lib/DateTime/Locale/sah.pod',
    'lib/DateTime/Locale/sah_RU.pod',
    'lib/DateTime/Locale/saq.pod',
    'lib/DateTime/Locale/saq_KE.pod',
    'lib/DateTime/Locale/sat.pod',
    'lib/DateTime/Locale/sat_Deva.pod',
    'lib/DateTime/Locale/sat_Deva_IN.pod',
    'lib/DateTime/Locale/sat_Olck.pod',
    'lib/DateTime/Locale/sat_Olck_IN.pod',
    'lib/DateTime/Locale/sbp.pod',
    'lib/DateTime/Locale/sbp_TZ.pod',
    'lib/DateTime/Locale/sc.pod',
    'lib/DateTime/Locale/sc_IT.pod',
    'lib/DateTime/Locale/scn.pod',
    'lib/DateTime/Locale/scn_IT.pod',
    'lib/DateTime/Locale/sd.pod',
    'lib/DateTime/Locale/sd_Arab.pod',
    'lib/DateTime/Locale/sd_Arab_PK.pod',
    'lib/DateTime/Locale/sd_Deva.pod',
    'lib/DateTime/Locale/sd_Deva_IN.pod',
    'lib/DateTime/Locale/sdh.pod',
    'lib/DateTime/Locale/sdh_IQ.pod',
    'lib/DateTime/Locale/sdh_IR.pod',
    'lib/DateTime/Locale/se.pod',
    'lib/DateTime/Locale/se_FI.pod',
    'lib/DateTime/Locale/se_NO.pod',
    'lib/DateTime/Locale/se_SE.pod',
    'lib/DateTime/Locale/seh.pod',
    'lib/DateTime/Locale/seh_MZ.pod',
    'lib/DateTime/Locale/ses.pod',
    'lib/DateTime/Locale/ses_ML.pod',
    'lib/DateTime/Locale/sg.pod',
    'lib/DateTime/Locale/sg_CF.pod',
    'lib/DateTime/Locale/shi.pod',
    'lib/DateTime/Locale/shi_Latn.pod',
    'lib/DateTime/Locale/shi_Latn_MA.pod',
    'lib/DateTime/Locale/shi_Tfng.pod',
    'lib/DateTime/Locale/shi_Tfng_MA.pod',
    'lib/DateTime/Locale/shn.pod',
    'lib/DateTime/Locale/shn_MM.pod',
    'lib/DateTime/Locale/shn_TH.pod',
    'lib/DateTime/Locale/si.pod',
    'lib/DateTime/Locale/si_LK.pod',
    'lib/DateTime/Locale/sid.pod',
    'lib/DateTime/Locale/sid_ET.pod',
    'lib/DateTime/Locale/sk.pod',
    'lib/DateTime/Locale/sk_SK.pod',
    'lib/DateTime/Locale/skr.pod',
    'lib/DateTime/Locale/skr_PK.pod',
    'lib/DateTime/Locale/sl.pod',
    'lib/DateTime/Locale/sl_SI.pod',
    'lib/DateTime/Locale/sma.pod',
    'lib/DateTime/Locale/sma_NO.pod',
    'lib/DateTime/Locale/sma_SE.pod',
    'lib/DateTime/Locale/smj.pod',
    'lib/DateTime/Locale/smj_NO.pod',
    'lib/DateTime/Locale/smj_SE.pod',
    'lib/DateTime/Locale/smn.pod',
    'lib/DateTime/Locale/smn_FI.pod',
    'lib/DateTime/Locale/sms.pod',
    'lib/DateTime/Locale/sms_FI.pod',
    'lib/DateTime/Locale/sn.pod',
    'lib/DateTime/Locale/sn_ZW.pod',
    'lib/DateTime/Locale/so.pod',
    'lib/DateTime/Locale/so_DJ.pod',
    'lib/DateTime/Locale/so_ET.pod',
    'lib/DateTime/Locale/so_KE.pod',
    'lib/DateTime/Locale/so_SO.pod',
    'lib/DateTime/Locale/sq.pod',
    'lib/DateTime/Locale/sq_AL.pod',
    'lib/DateTime/Locale/sq_MK.pod',
    'lib/DateTime/Locale/sq_XK.pod',
    'lib/DateTime/Locale/sr.pod',
    'lib/DateTime/Locale/sr_Cyrl.pod',
    'lib/DateTime/Locale/sr_Cyrl_BA.pod',
    'lib/DateTime/Locale/sr_Cyrl_ME.pod',
    'lib/DateTime/Locale/sr_Cyrl_RS.pod',
    'lib/DateTime/Locale/sr_Cyrl_XK.pod',
    'lib/DateTime/Locale/sr_Latn.pod',
    'lib/DateTime/Locale/sr_Latn_BA.pod',
    'lib/DateTime/Locale/sr_Latn_ME.pod',
    'lib/DateTime/Locale/sr_Latn_RS.pod',
    'lib/DateTime/Locale/sr_Latn_XK.pod',
    'lib/DateTime/Locale/ss.pod',
    'lib/DateTime/Locale/ss_SZ.pod',
    'lib/DateTime/Locale/ss_ZA.pod',
    'lib/DateTime/Locale/ssy.pod',
    'lib/DateTime/Locale/ssy_ER.pod',
    'lib/DateTime/Locale/st.pod',
    'lib/DateTime/Locale/st_LS.pod',
    'lib/DateTime/Locale/st_ZA.pod',
    'lib/DateTime/Locale/su.pod',
    'lib/DateTime/Locale/su_Latn.pod',
    'lib/DateTime/Locale/su_Latn_ID.pod',
    'lib/DateTime/Locale/sv.pod',
    'lib/DateTime/Locale/sv_AX.pod',
    'lib/DateTime/Locale/sv_FI.pod',
    'lib/DateTime/Locale/sv_SE.pod',
    'lib/DateTime/Locale/sw.pod',
    'lib/DateTime/Locale/sw_CD.pod',
    'lib/DateTime/Locale/sw_KE.pod',
    'lib/DateTime/Locale/sw_TZ.pod',
    'lib/DateTime/Locale/sw_UG.pod',
    'lib/DateTime/Locale/syr.pod',
    'lib/DateTime/Locale/syr_IQ.pod',
    'lib/DateTime/Locale/syr_SY.pod',
    'lib/DateTime/Locale/szl.pod',
    'lib/DateTime/Locale/szl_PL.pod',
    'lib/DateTime/Locale/ta.pod',
    'lib/DateTime/Locale/ta_IN.pod',
    'lib/DateTime/Locale/ta_LK.pod',
    'lib/DateTime/Locale/ta_MY.pod',
    'lib/DateTime/Locale/ta_SG.pod',
    'lib/DateTime/Locale/te.pod',
    'lib/DateTime/Locale/te_IN.pod',
    'lib/DateTime/Locale/teo.pod',
    'lib/DateTime/Locale/teo_KE.pod',
    'lib/DateTime/Locale/teo_UG.pod',
    'lib/DateTime/Locale/tg.pod',
    'lib/DateTime/Locale/tg_TJ.pod',
    'lib/DateTime/Locale/th.pod',
    'lib/DateTime/Locale/th_TH.pod',
    'lib/DateTime/Locale/ti.pod',
    'lib/DateTime/Locale/ti_ER.pod',
    'lib/DateTime/Locale/ti_ET.pod',
    'lib/DateTime/Locale/tig.pod',
    'lib/DateTime/Locale/tig_ER.pod',
    'lib/DateTime/Locale/tk.pod',
    'lib/DateTime/Locale/tk_TM.pod',
    'lib/DateTime/Locale/tn.pod',
    'lib/DateTime/Locale/tn_BW.pod',
    'lib/DateTime/Locale/tn_ZA.pod',
    'lib/DateTime/Locale/to.pod',
    'lib/DateTime/Locale/to_TO.pod',
    'lib/DateTime/Locale/tok.pod',
    'lib/DateTime/Locale/tok_001.pod',
    'lib/DateTime/Locale/tpi.pod',
    'lib/DateTime/Locale/tpi_PG.pod',
    'lib/DateTime/Locale/tr.pod',
    'lib/DateTime/Locale/tr_CY.pod',
    'lib/DateTime/Locale/tr_TR.pod',
    'lib/DateTime/Locale/trv.pod',
    'lib/DateTime/Locale/trv_TW.pod',
    'lib/DateTime/Locale/trw.pod',
    'lib/DateTime/Locale/trw_PK.pod',
    'lib/DateTime/Locale/ts.pod',
    'lib/DateTime/Locale/ts_ZA.pod',
    'lib/DateTime/Locale/tt.pod',
    'lib/DateTime/Locale/tt_RU.pod',
    'lib/DateTime/Locale/twq.pod',
    'lib/DateTime/Locale/twq_NE.pod',
    'lib/DateTime/Locale/tyv.pod',
    'lib/DateTime/Locale/tyv_RU.pod',
    'lib/DateTime/Locale/tzm.pod',
    'lib/DateTime/Locale/tzm_MA.pod',
    'lib/DateTime/Locale/ug.pod',
    'lib/DateTime/Locale/ug_CN.pod',
    'lib/DateTime/Locale/uk.pod',
    'lib/DateTime/Locale/uk_UA.pod',
    'lib/DateTime/Locale/und.pod',
    'lib/DateTime/Locale/ur.pod',
    'lib/DateTime/Locale/ur_IN.pod',
    'lib/DateTime/Locale/ur_PK.pod',
    'lib/DateTime/Locale/uz.pod',
    'lib/DateTime/Locale/uz_Arab.pod',
    'lib/DateTime/Locale/uz_Arab_AF.pod',
    'lib/DateTime/Locale/uz_Cyrl.pod',
    'lib/DateTime/Locale/uz_Cyrl_UZ.pod',
    'lib/DateTime/Locale/uz_Latn.pod',
    'lib/DateTime/Locale/uz_Latn_UZ.pod',
    'lib/DateTime/Locale/vai.pod',
    'lib/DateTime/Locale/vai_Latn.pod',
    'lib/DateTime/Locale/vai_Latn_LR.pod',
    'lib/DateTime/Locale/vai_Vaii.pod',
    'lib/DateTime/Locale/vai_Vaii_LR.pod',
    'lib/DateTime/Locale/ve.pod',
    'lib/DateTime/Locale/ve_ZA.pod',
    'lib/DateTime/Locale/vec.pod',
    'lib/DateTime/Locale/vec_IT.pod',
    'lib/DateTime/Locale/vi.pod',
    'lib/DateTime/Locale/vi_VN.pod',
    'lib/DateTime/Locale/vmw.pod',
    'lib/DateTime/Locale/vmw_MZ.pod',
    'lib/DateTime/Locale/vo.pod',
    'lib/DateTime/Locale/vo_001.pod',
    'lib/DateTime/Locale/vun.pod',
    'lib/DateTime/Locale/vun_TZ.pod',
    'lib/DateTime/Locale/wa.pod',
    'lib/DateTime/Locale/wa_BE.pod',
    'lib/DateTime/Locale/wae.pod',
    'lib/DateTime/Locale/wae_CH.pod',
    'lib/DateTime/Locale/wal.pod',
    'lib/DateTime/Locale/wal_ET.pod',
    'lib/DateTime/Locale/wbp.pod',
    'lib/DateTime/Locale/wbp_AU.pod',
    'lib/DateTime/Locale/wo.pod',
    'lib/DateTime/Locale/wo_SN.pod',
    'lib/DateTime/Locale/xh.pod',
    'lib/DateTime/Locale/xh_ZA.pod',
    'lib/DateTime/Locale/xnr.pod',
    'lib/DateTime/Locale/xnr_IN.pod',
    'lib/DateTime/Locale/xog.pod',
    'lib/DateTime/Locale/xog_UG.pod',
    'lib/DateTime/Locale/yav.pod',
    'lib/DateTime/Locale/yav_CM.pod',
    'lib/DateTime/Locale/yi.pod',
    'lib/DateTime/Locale/yi_UA.pod',
    'lib/DateTime/Locale/yo.pod',
    'lib/DateTime/Locale/yo_BJ.pod',
    'lib/DateTime/Locale/yo_NG.pod',
    'lib/DateTime/Locale/yrl.pod',
    'lib/DateTime/Locale/yrl_BR.pod',
    'lib/DateTime/Locale/yrl_CO.pod',
    'lib/DateTime/Locale/yrl_VE.pod',
    'lib/DateTime/Locale/yue.pod',
    'lib/DateTime/Locale/yue_Hans.pod',
    'lib/DateTime/Locale/yue_Hans_CN.pod',
    'lib/DateTime/Locale/yue_Hant.pod',
    'lib/DateTime/Locale/yue_Hant_HK.pod',
    'lib/DateTime/Locale/za.pod',
    'lib/DateTime/Locale/za_CN.pod',
    'lib/DateTime/Locale/zgh.pod',
    'lib/DateTime/Locale/zgh_MA.pod',
    'lib/DateTime/Locale/zh.pod',
    'lib/DateTime/Locale/zh_Hans.pod',
    'lib/DateTime/Locale/zh_Hans_CN.pod',
    'lib/DateTime/Locale/zh_Hans_HK.pod',
    'lib/DateTime/Locale/zh_Hans_MO.pod',
    'lib/DateTime/Locale/zh_Hans_SG.pod',
    'lib/DateTime/Locale/zh_Hant.pod',
    'lib/DateTime/Locale/zh_Hant_HK.pod',
    'lib/DateTime/Locale/zh_Hant_MO.pod',
    'lib/DateTime/Locale/zh_Hant_TW.pod',
    'lib/DateTime/Locale/zu.pod',
    'lib/DateTime/Locale/zu_ZA.pod',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/alias.t',
    't/basic.t',
    't/be-tarask.t',
    't/code-case-insensitive.t',
    't/format-length.t',
    't/iso639-2.t',
    't/load-from-relative-inc-path.t',
    't/load-name.t',
    't/locale-data-is-cloned.t',
    't/prefers-24-hour-time.t',
    't/register-from-data.t',
    't/register.t',
    't/script.t',
    't/storable.t',
    't/taint.t',
    't/version-check.t',
    't/zzz-check-breaks.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
